importFrom("methods", "new")
exportClasses("fingerprint")
exportClasses("featvec")
exportClasses("feature")
exportMethods("fold", "euc.vector", "distance",
              "random.fingerprint", "as.character",
              "length", 
              "feature", "count", 'feature<-', 'count<-')
export("fp.sim.matrix", "fp.to.matrix", "fp.factor.matrix",
       "fp.read.to.matrix", "fp.read","shannon",
       ##"featvec.to.binaryfp",
       "moe.lf", "bci.lf", "cdk.lf", "ecfp.lf", "fps.lf", "jchem.binary.lf",
       "bit.spectrum", "balance", "bit.importance")
useDynLib(fingerprint,.registration = TRUE)
